#!/usr/bin/env python
"""
move unfinished tasks back to heap
"""
import os, sys, glob, yaml, subprocess
from yui import tsklib

def main():
    argv = sys.argv;
    argv.pop(0); # remove first element, pointing to script itself
    if len(argv) != 1 :
        print("""
        Usage:
            """+tsklib.cmd+""" reset %taskId%   - move single task back to heap by id
            """+tsklib.cmd+""" reset id%taskId%   - move single task back to heap by id
            """+tsklib.cmd+""" reset cur%taskNum%   - move single task back to heap, using order number from """+tsklib.cmd+""" list cur
            """+tsklib.cmd+""" reset all        - move all unfinished tasks back to heap
        Example:
            """+tsklib.cmd+""" pick 3
            """+tsklib.cmd+""" pick id3
            """+tsklib.cmd+""" pick cur3
            """)
        exit(1);
        pass;
    id = argv[0]
    tasks = []

    if id == "all":
        tasks = tsklib.listTasks( "cur" );
        pass
    else:
        tasks.append( tsklib.getTaskByIdOrNum( id, "cur") )
        pass
    
    if len(tasks) == 0:
        print("task with id="+id+" not found in cur")
        exit(1)
        pass

    for task in tasks:
        if task["status"] in ["done","fail"] :
            continue
        pass
        targetPath = tsklib.tskpath() + "/heap/"+task["status"]
        os.makedirs(targetPath, exist_ok=True)
        print("moving " + task["filename"] + " back to heap .. ", end="")
        os.rename( task["fullfilename"], targetPath + "/" + task["filename"]);
        print("done")
    pass
    tsklib.gitAddCommitTask("reset "+id);
    pass

if __name__=="__main__":
    main()
    pass





#!/usr/bin/env python
import os, sys, glob, yaml, subprocess, datetime
from yui import tsklib

def main():
    argv = sys.argv;
    argv.pop(0); # remove first element, pointing to script itself
    if len(argv) != 1 :
        print("""
        Usage:
            """+tsklib.cmd+""" archive %date%      - move done tasks from .yet/cur to archive with specific date
        Example:
            """+tsklib.cmd+""" archive today // bug here, uses UTC date, instead of local date
            """+tsklib.cmd+""" archive yesterday
            """+tsklib.cmd+""" archive 2023-01-03
            """)
        exit(1);
        pass;
    date = argv[0]
    if( date == "today" ):
        date = datetime.date.today().strftime("%Y-%m-%d")
        pass
    if( date == "yesterday" ):
        date = (datetime.date.today() - datetime.timedelta(days = 1)).strftime("%Y-%m-%d")
        pass

    files = tsklib.findTaskFiles("cur", "*.md")
    if len(files) == 0:
        print("No tasks found")
        exit(1)
        pass

    for filename in files:
        task =  tsklib.loadYaml(filename) 
        if task["status"] not in ["done","fail"]:
            continue
        pass
        targetPath = tsklib.tskpath() + "/"+date+"/"+task["status"]
        os.makedirs(targetPath, exist_ok=True)
        print("moving " + task["filename"] + " to "+date+" .. ", end="")
        os.rename( filename, targetPath + "/" + task["filename"]);
        print("done")
    pass
    tsklib.gitAddCommitTask("reset "+str(id));
    pass

if __name__=="__main__":
    main()
    pass



#!/usr/bin/env python
import os, sys
from yui import tsklib


def main():
    argv = sys.argv;
    argv.pop(0); # remove first element, pointing to script itself
    home = os.path.expanduser("~");
    curpath = os.getcwd();
    os.chdir(tsklib.tskpath());
    os.system("git "+' '.join(argv));
    os.chdir(curpath);
    pass

if __name__=="__main__":
    main()
    pass






#!/usr/bin/env python
import os, sys;
from yui import tsklib

def main():
    if not tsklib.gitExist():
        print(tsklib.color("yellow")+"[warning] git not found, install git to enable task history"+tsklib.color("noColor"));
        pass
    argv = sys.argv;
    argv.pop(0); # remove first element, pointing to script itself
    if len(argv) == 0 :
        print("""
    Usage:
        """+tsklib.cmd+""" create %taskname%   - create new task, return taskId and filename
        # """+tsklib.cmd+""" list                - show current tasks
        """+tsklib.cmd+""" list heap           - show tasks from heap
        """+tsklib.cmd+""" list cur            - show tasks for current date
        """+tsklib.cmd+""" pick %taskId%       - move tsak from heap to current date
        """+tsklib.cmd+""" lastid              - show last insert id
        """+tsklib.cmd+""" open %taskId%       - open task in kate (parallel kate filename.md)
        """+tsklib.cmd+""" reset               - move not finished tasks back to heap
        """+tsklib.cmd+""" archive             - move done tasks from cur to archive with date
        """+tsklib.cmd+""" scope               - change/reset scope ( current context and project ) affects avironment variables """+tsklib.cmd+"""_CONTEXT, """+tsklib.cmd+"""_PROJECT
        """+tsklib.cmd+""" drop                - Use with care! completely remove task with specific id
        """+tsklib.cmd+""" git %attributes%    - run git on ./"""+tsklib.cmd+""" folder
        
    Environmant variables:
        """+tsklib.cmd.upper()+"""_CONTEXT             - set context
        """+tsklib.cmd.upper()+"""_PROJECT             - set project
        """+tsklib.cmd.upper()+"""                     - short version for setting both project and context
        """+tsklib.cmd.upper()+"""_HOME                - working folder name inside AppData/home (~/."""+tsklib.cmd+"""_agavestorm is default value for Linux)
        
        Examples:
            """+tsklib.cmd.upper()+"""_PROJECT=myproj """+tsklib.cmd+""" create task decription
                                 - will create task with project parameter set to `myproj`
            """+tsklib.cmd.upper()+"""_CONTEXT=personal """+tsklib.cmd+""" list cur
                                 - will show only tasks in `personal` scope
            """+tsklib.cmd.upper()+"""=context:personal - equivalent for`"""+tsklib.cmd.upper()+"""_CONTEXT=personal
            """+tsklib.cmd.upper()+"""=context:personal,project:myproj
                                 - equivalent for `"""+tsklib.cmd.upper()+"""_CONTEXT=personal """+tsklib.cmd.upper()+"""_PROJECT=myproj """+tsklib.cmd+""" ...`
            """+tsklib.cmd.upper()+"""=p:proj,c:context - equivalent for `"""+tsklib.cmd.upper()+"""=context:personal,project:myproj` parameter order does not matter
            
        Priorities:
            """+tsklib.cmd.upper()+"""_CONTEXT, """+tsklib.cmd.upper()+"""_PROJECT - high
            """+tsklib.cmd.upper()+"""                      - middle
            scope.yaml               - low
            """);
        exit(1);
        pass

    os.system(tsklib.cmd+"-"+' '.join(argv)); # works same as tsklib.cmd-$@ in bash
    pass

if __name__=="__main__":
    main()
    pass



#!/usr/bin/env python
import os, sys, glob, yaml, subprocess, datetime
from yui import tsklib
from pathlib import Path
from sanitize_filename import sanitize

def main():
    argv = sys.argv;
    argv.pop(0); # remove first element, pointing to script itself
    if len(argv) == 0 :
        print("""
    Usage:
        """+tsklib.cmd+""" create %taskname%   - create new task
    Example:
        """+tsklib.cmd+""" create do this and do that
        """)
        exit(1);
        pass;
    tasknameArr = argv
    tsklib.createTask( " ".join(tasknameArr) )
    pass

if __name__=="__main__":
    main()
    pass




#!/usr/bin/env python
import os, glob, yaml, datetime, subprocess
from appdata import AppDataPaths
from sanitize_filename import sanitize
from pathlib import Path
from unidecode import unidecode
import platform

Title="Yui"
cmd="yui"
scopeNames = {
    "context":[],
    "project":[],
    }


def color( key ):
    linuxColors = {
        "red":"\033[1;31m",
        "green":"\033[1;32m",
        "yellow":"\033[1;93m",
        "gray":"\033[2;37m",
        "noColor":"\033[0m", # No Color
        }
    if key not in linuxColors.keys():
        return ""
    if platform.system() == "Windows":
        return ""
    return linuxColors[key]
    pass

def statusColor( status ):
    colorMap = {
        "new" : "red",
        "work" : "yellow",
        "done" : "green",
        "fail" : "green",
        }
    if status not in colorMap.keys():
        return ""
    return color( colorMap[ status ] )
    pass

def tskpath():
    default=cmd
    home = os.getenv("YUI_HOME", default)
    if platform.system() == "Windows":
        home = os.getenv('LOCALAPPDATA')+"/"+home 
        pass
    path = AppDataPaths(home).app_data_path
    os.makedirs(path, exist_ok=True)
    return path
    pass

def getTaskFilenameById(id, location="*"):
    files = findTaskFiles( location, "*."+id+".md")
    if len(files) == 0:
        suffix = ""
        if location !="*":
            suffix = " in "+location
        print("task with id="+id+" not found"+suffix)
        exit(1)
    pass;
    if len(files) != 1:
        print("more than one task with id="+id+" found. That should never happen")
        exit(1)
    pass;
    return files[0]
    pass

def getTaskFilenameByIdOrNum( idOrNum, location="*"):
    if idOrNum.isnumeric():
        return getTaskFilenameById( idOrNum, location )
        pass
    if idOrNum[:2] == "id":
        return getTaskFilenameById( idOrNum[2:], location )
        pass
    if idOrNum[:3] == "cur":
        return getTaskFilenameByNum( idOrNum[3:], "cur")
        pass
    if idOrNum[:4] == "heap":
        return getTaskFilenameByNum( idOrNum[4:], "heap")
        pass
    print("Unknown task id or number format");
    pass

def getTaskByIdOrNum( idOrNum, location="*"):
    if idOrNum.isnumeric():
        return getTaskById( idOrNum, location )
        pass
    if idOrNum[:2] == "id":
        return getTaskById( idOrNum[2:], location )
        pass
    if idOrNum[:3] == "cur":
        return getTaskByNum( idOrNum[3:], "cur")
        pass
    if idOrNum[:4] == "heap":
        return getTaskByNum( idOrNum[4:], "heap")
        pass
    print("Unknown task id or number format");
    pass



def getTaskFilenameByNum( num, location ):
    return getTaskByNum( num, location )["fullfilename"]
    pass

def getTaskById(id, location="*"):
    filename = getTaskFilenameById( str(id), location )
    task = loadYaml( filename )
    task["fullfilename"] = filename
    return task
    pass

def getTasksByIds( ids ):
    re = []
    for id in ids:
        re.append( getTaskById(id) )
        pass
    return re
    pass    

def getTaskByNum( num, location ):
    tasks = listTasks( location )
    for task in tasks:
        if int(task["No."]) == int(num):
            return task
    print("Task "+num+" not found in "+location)
    pass



def findTaskFiles(location, pattern):
    return glob.glob( tskpath() + "/"+location+"/*/"+pattern)
    pass

def listTasks(location, useScope=True):
    scope = getScope();
    files = findTaskFiles( location, "*.md" )
    tasks = []
    for filename in files:
        task = loadYaml(filename)
        task["fullfilename"] = filename
        addItem = True
        for key in scope:
            addItem = addItem and ( scope[key] == "" or scope[key] == task[key] )
            pass
        if useScope and not addItem:
            continue
            pass
        tasks.append( task )
        pass
    tasks = sorted(tasks, key = lambda task : task["id"])
    key = 0
    for task in tasks:
        key = key+1
        task["No."] = key
        pass
    return tasks
    pass

def getConfigParam(param):
    return loadYaml( tskpath() + "/config.yaml" )[param]
    pass

def loadYaml(filename):
    with open( filename, 'rb' ) as f:
        return next(yaml.load_all(f, Loader=yaml.loader.UnsafeLoader))
        pass
    pass

def saveYaml(filename, data):
    with open( filename, 'w' ) as f:
        yaml.dump( data, f )
        pass
    pass

def gitExist()->bool:
    try:
        re = subprocess.run(["git","-v"], stdout=subprocess.DEVNULL, stderr=subprocess.DEVNULL)
    except:
        return False
    return re.returncode == 0
    pass

def gitInitIfNotPresent():
    workingdir = tskpath()
    if os.path.isdir( workingdir+"/.git"):
        return
        pass
    curpath = os.getcwd();
    os.chdir(workingdir);
    os.system("git init > /dev/null");
    os.chdir(curpath);
    pass

def gitAddCommitTask(message):
    if not gitExist():
        print("git not exist");
        return
        pass
    gitInitIfNotPresent()
    curpath = os.getcwd();
    os.chdir(tskpath());
    os.system("git add ./*.md > /dev/null && git commit -m '"+message+"' > /dev/null");
    os.chdir(curpath);
    pass

def getLastId():
    files = findTaskFiles("*", "*.md")
    maxId = -1
    for filename in files :
        # Open the file and load the file
        id = loadYaml( filename )["id"]
        if id > maxId:
            maxId = id
            pass
        pass
    return maxId
    pass

def newScope():
    return {
        "project":"",
        "context":""
        }
    pass

def loadScope():
    scope = newScope()
    try:
        data = loadYaml( tskpath()+"/scope.yaml")
        for key in scope:
            try:
                scope[key] = data[key]
            except:
                pass
            pass
    except:
        pass
    return scope
    pass

def mergeScope( orig, changes ):
    scope = orig
    for key in changes:
        if changes[key] == "":
            continue
        scope[key] = changes[key]
    return scope
    pass

def parseFilter( filterstring ):
    scope = newScope()
    if filterstring == "":
        return scope
        pass
    # split by ,
    pairs = filterstring.split(",")
    for pair in pairs:
        keyvalue = pair.split(":")
        key = keyvalue[0]
        value = keyvalue[1]
        if key == "c":
            key = "context"
            pass
        if key == "p":
            key = "project"
            pass
        scope[key] = value
        pass
    return scope
    pass

def getDefaultContextForProject( projectName ):
    try:
        return loadYaml( tskpath() + "/projects/" + projectName + ".yaml")["defaultContext"]
    except:
        return ""
    pass

def getScope():
    scope = loadScope()
    scope = mergeScope( scope, parseFilter(os.getenv(cmd.upper(),"")) )
    for key in scope:
        scope[key] = os.getenv(cmd.upper() + "_" + key.upper(), scope[key])
        pass
    if scope["context"] == "" and scope["project"] != "":
        scope["context"] = getDefaultContextForProject( scope["project"] )
        pass
    return scope
    pass

def saveScope( scope ):
    saveYaml( tskpath()+"/scope.yaml", scope)
    pass

def createTask( name ):
    name = name.strip()
    if name == "":
        return
    name = name.replace("\"","'")
    tasknameArr = name.split(" ")
    taskname = '_'.join( tasknameArr )
    taskname = unidecode( taskname )
    taskname = sanitize( taskname ).replace("'","").replace("\"","").replace("`","")
    taskDatetime = datetime.datetime.today()
    id = str( int( getLastId() )+1 )
    path = tskpath() + "/heap/new"
    filename = taskDatetime.strftime("%Y-%m-%d_%H.%M.%S_%z_")+taskname+"."+id+".md"
    os.makedirs(path, exist_ok=True)

    scope = getScope()

    Path( path + "/" + filename ).write_text("""---
name: \""""+name+"""\"
created: """+taskDatetime.strftime("%Y-%m-%d %H:%M:%S %z")+"""
context: """+scope["context"]+"""
project: """+scope["project"]+"""
filename:  """+filename+"""
status: new
id: """+id+"""
---
""", encoding='utf-8')
    
    gitAddCommitTask("created "+id);
    pass

def pickTask(id):
    filename = getTaskFilenameByIdOrNum(id, "heap")
    task = loadYaml(filename)
    targetPath = tskpath() + "/cur/" + task["status"]
    os.makedirs(targetPath, exist_ok=True)
    os.rename( filename, targetPath + "/" + task["filename"]);
    gitAddCommitTask("pick "+id);
    pass

def rangeQueryToArray(query):
    tasks = listTasks("heap")
    taskIds = []
    if ".." in query:
        for task in tasks:
            taskIds.append( task["id"] )
            pass
        pass
    #print(taskIds)
    ids = []
    queryElements = query.split(",")
    for queryElement in queryElements:
        taskRange = queryElement.split("..")
        if len(taskRange) == 1:
            ids.append( queryElement )
            continue
        pass
        if len(taskRange) > 2:
            raise Exception("Mailformed id range query")
        pass
        for item in range(int(taskRange[0]), int(taskRange[1])+1): # TODO generalize for curNNN, heapNNN
            if item in taskIds:
                ids.append(str(item))
                pass
            pass
        pass
    return ids
    pass

def pickTasks(query):
    '''
    pick one or more tasks using array and range, like pick 141,142,143..150
    pick only from results of listTasks(heap)
    '''
    pickTasksByIds( rangeQueryToArray(query) )
    pass

def pickTasksByIds( ids ):
    for id in ids:
        pickTask( str(id) )
        pass
    pass

def resetTask(idOrNum):
    task = getTaskByIdOrNum(idOrNum)
    if task["status"] in ["done","fail"]:
        return
        pass
    targetPath = tskpath() + "/heap/"+task["status"]
    os.makedirs(targetPath, exist_ok=True)
    os.rename( task["fullfilename"], targetPath + "/" + task["filename"]);
    pass

def resetTasksByIds( ids ):
    for id in ids:
        resetTask( str(id) )
        pass
    pass

def dropTask( id ):
    file = getTaskFilenameByIdOrNum(id)
    os.remove(file)
    pass

def dropTasksByIds(ids):
    for id in ids:
        dropTask( str(id) )
        pass
    pass

def loadScopeNames():
    tasks = listTasks("heap", useScope=False) + listTasks("cur", useScope=False)
    #print( tasks )
    for task in tasks:
        for key in ["context","project"]:
            if task[key] not in scopeNames[key]:
                if task[key] == None:
                    continue
                pass
                scopeNames[key].append( task[key] )
            pass
        pass
    print( scopeNames )
    pass

def getScopeNames( key ):
    if len( scopeNames[key]) == 0:
        loadScopeNames()
    return scopeNames[key]
    pass




#!/usr/bin/env python
import os, sys, glob, yaml, subprocess, datetime
from yui import tsklib
from pathlib import Path

def main():
    argv = sys.argv;
    argv.pop(0); # remove first element, pointing to script itself
    if len(argv) == 0 :
        print("""
    Usage:
        """+tsklib.cmd+""" scope reset
        """+tsklib.cmd+""" scope context contextName
        """+tsklib.cmd+""" scope project projectName
        """+tsklib.cmd+""" scope list
            """)
        exit(1);
        pass;

    command = argv[0]
    scope = tsklib.getScope();
    if command == "list":
        for key in scope:
            print("Name: "+key+" = "+scope[key] )
        exit(0)
        pass

    if command == "reset":
        tsklib.saveScope({})
        exit(0)
        pass

    if not command in scope.keys():
        print("Unexpected parameter "+command)
        exit(1)
        pass

    argv.pop(0)
    value = " ".join(argv)
    scope[command] = value
    tsklib.saveScope( scope )
    pass

if __name__=="__main__":
    main()
    pass



#!/usr/bin/env python
import os, sys, glob, yaml, subprocess
from yui import tsklib

def main():
    argv = sys.argv;
    argv.pop(0); # remove first element, pointing to script itself
    if len(argv) != 1 :
        print("""
        open single task with text editor ( see ~/.tsk/config.yaml )
        Usage:
            """+tsklib.cmd+""" open %taskId%   - by default parameter is interprited as taskId
            """+tsklib.cmd+""" open id%taskId%   - parameter is task id
            """+tsklib.cmd+""" open cur%taskNo%   - parameter is task order number as it is shown by `"""+tsklib.cmd+""" list cur` command
            """+tsklib.cmd+""" open heap%taskNo%   - parameter is task order number as it is shown by `"""+tsklib.cmd+""" list heap` command
        Examples:
            """+tsklib.cmd+""" open 3
            """+tsklib.cmd+""" open id3
            """+tsklib.cmd+""" open cur1
            """+tsklib.cmd+""" open heap1            
            """)
        exit(1);
        pass;
    id = argv[0]
    filename = tsklib.getTaskFilenameByIdOrNum(id)
    #print("filename: "+filename)
    try:
        editor = tsklib.getConfigParam("editor")
    except:
        candidates = [ os.getenv("EDITOR"), "mcedit","nano", "vim", "vi","ee"]
        for candidate in candidates:
            if subprocess.call("which " + candidate + "> /dev/null", shell=True) == 0:
                editor = candidate+" %"
                break
            pass
    if editor=="":
        print("Can't detect text editor, use "+tsklib.tskpath()+"/config.yaml to specify");
        exit(1);
        pass

    cmd = editor.replace("%", filename)
    subprocess.call( cmd, shell=True );
    pass

if __name__=="__main__":
    main()
    pass



#!/usr/bin/env python
import os, sys, glob, yaml, subprocess, datetime
from yui import tsklib
from pathlib import Path



def addTitle( dataString, title ):
    gap = 2
    titleString = "[ "+title+" ]"
    if title == "cur":
        titleString = "[ Current tasks ]"
        pass
    if title == "heap":
        titleString = "[ Heap/Backlog ]"
        pass
    startPos = len(dataString) - gap - len(titleString)
    return dataString[0:startPos] + titleString + dataString[startPos+len(titleString):len(dataString)]
    pass


def main():
    argv = sys.argv;
    argv.pop(0); # remove first element, pointing to script itself
    noColor = tsklib.color("noColor")
    if len(argv) == 0 :
        print("""
        Usage:
            """+tsklib.cmd+""" list heap   - list task from heap / global backlog
            """+tsklib.cmd+""" list cur    - list task picked for current day
            """)
        exit(1);
        pass;

    location = argv[0]

    def mb_strlen( s ):
        return len(str(s)) #.encode('utf-16-le'))
        pass

    tasks = tsklib.listTasks( location )

    if len(tasks) == 0:
        print("No tasks found in "+location+noColor)
        exit(1)
        pass
    keys = ["No.", "id", "context", "project", "name", "status"];

    maxLenghts = {};
    for key in keys:
        #print(key)
        maxLenghts[key] = mb_strlen(key);
        for task in tasks:
            length = mb_strlen(task[key]);
            if length > maxLenghts[key]:
                maxLenghts[key] = length;
                pass
            pass
        pass

    columnNames = {};
    horizontalLines = {};
    rows = []
    for task in tasks:
        rows.append({})
        pass
    for key in keys:
        columnNames[key] = key.ljust( maxLenghts[key])
        horizontalLines[key] = "".ljust( maxLenghts[key], "─")
        for i, task in enumerate(tasks):
            rows[i][key] = str(task[key]).ljust( maxLenghts[key] )
            pass
        pass

    print("╭─"+"─┬─".join(horizontalLines.values())+"─╮");
    print("│ "+" │ ".join(columnNames.values()    )+" │");
    print("├─"+"─┼─".join(horizontalLines.values())+"─┤");
    for i, task in enumerate(tasks):
        row = rows[i]
        color = tsklib.statusColor( task["status"] )
        print("│ "+color+(noColor+" │ "+color).join(row.values())+noColor+" │")
        pass
    print( addTitle("╰─"+"─┴─".join(horizontalLines.values())+"─╯", location ))
    print( tsklib.color("gray")+"  ", end="" )
    if location == "heap":
        print("Hint: use `"+tsklib.cmd+" pick %taskId%` to pick task from the Heap to Current tasks ")
        pass
    if location == "cur":
        print("""Hint: use `"""+tsklib.cmd+""" open` to open task in text editor, `"""+tsklib.cmd+""" reset` to move task(s) back to the Heap, `"""+tsklib.cmd+""" archive` to archive done tasks""")
        pass

    print(tsklib.color("noColor"))
    pass

if __name__ == "__main__":
    main()
    pass



#!/usr/bin/env python
import os, sys, glob
from yui import tsklib


def main():
    argv = sys.argv;
    argv.pop(0); # remove first element, pointing to script itself
    if len(argv) != 1 :
        print("""
        completely remove single task with specified id or order number
        Usage:
            """+tsklib.cmd+""" drop %taskId%        - use task id
            """+tsklib.cmd+""" drop id%taskId%      - use task id
            """+tsklib.cmd+""" drop cur%taskNum%    - use order number from `"""+tsklib.cmd+""" list cur`
            """+tsklib.cmd+""" drop heap%taskNum%   - use order number from `"""+tsklib.cmd+""" list heap`
        Example:
            """+tsklib.cmd+""" drop 3
            """+tsklib.cmd+""" drop id3
            """+tsklib.cmd+""" drop cur1
            """+tsklib.cmd+""" drop heap2
            """)
        exit(1);
        pass;
    id = argv[0]
    file = tsklib.getTaskFilenameByIdOrNum(id)
    print("Deleting task "+file+" .. ", end="")
    os.remove(file)
    print("done")
    pass

if __name__=="__main__":
    main()
    pass




import os,platform

def color( key ):
    linuxColors = {
        "red":"\033[1;31m",
        "green":"\033[1;32m",
        "yellow":"\033[1;93m",
        "gray":"\033[2;37m",
        "noColor":"\033[0m", # No Color
        }
    windowsColors = {
        "red":"4",
        "green":"2",
        "yellow":"6",
        "gray":"8",
        "noColor":"7", # No Color        
        }
    if platform.system() == "Windows":
        os.system("color "+windowsColors[key])
        return
    print(linuxColors[key], end="")
    pass
#print("|", end="")
color("green")
print("|", end="")
print("greentext", end="")
print("|")
#color("noColor")
#print("|")



#!/usr/bin/env python
import os, sys, glob, yaml, subprocess
from yui import tsklib

def main():
    argv = sys.argv;
    argv.pop(0); # remove first element, pointing to script itself
    if len(argv) != 1 :
        print("""
        pick single task to current day
        Usage:
            """+tsklib.cmd+""" pick %taskId%
            """+tsklib.cmd+""" pick id%taskId%
            """+tsklib.cmd+""" pick heap%taskNum%  - taskNum is order number from `"""+tsklib.cmd+""" list heap` command
            """+tsklib.cmd+""" pick %taskId1%,%taskId2%,%taskId3%,%taskId4%..%taskId100%    - pick array of ids and/or ranges of ids
        Example:
            """+tsklib.cmd+""" pick 3
            """+tsklib.cmd+""" pick id3
            """+tsklib.cmd+""" pick heap1
            """+tsklib.cmd+""" pick 141,142,143..150
            """)
        exit(1);
        pass;
    tsklib.pickTasks( argv[0] )
    pass

if __name__=="__main__":
    main()
    pass

